@@ -2,6 +2,8 @@ import requests
 import json
 import sys
 import os
+import functools
+import operator
 
 def get_my_ip():
     url = 'https://api.myip.com'
@@ -28,6 +30,15 @@ def get_base_path():
         return  PATH_BASE
     else:
         return curdir_path
+    
+def flat_list(List_2D):   
+    List_flat = functools.reduce(operator.iconcat, List_2D, [])    
+    return List_flat
+
+def validar_directorio(path):
+    if os.path.isdir(path)==False:
+        os.makedirs(path)
+
 
 def main():
     print(get_my_ip())
